
{% if instance.paging_show %}
    <div>
        <a href="{% if items.has_previous %}?{{ page_param_name }}={{ items.previous_page_number }}{% else %}#{% endif %}" aria-label="Previous">
            <span aria-hidden="true">&laquo;</span>
        </a>

        {% for page in items.paginator.page_range %}
            <a href="?{{ page_param_name }}={{ page }}">{{ page }}</a>
        {% endfor %}

        <a href="{% if items.has_next %}?{{ page_param_name }}={{ items.next_page_number }}{% else %}#{% endif %}" aria-label="Next">
            <span aria-hidden="true">&raquo;</span>
        </a>
    </div>
{% endif %}
