{% load i18n %}

<form method="post">
    {% csrf_token %}
    {{ form.email.label_tag }}
    {{ form.email }}
    {% if instance.fullname_show %}
        {{ form.first_name.label_tag }}
        {{ form.first_name }}
        {{ form.last_name.label_tag }}
        {{ form.last_name }}
    {% endif %}
    <input type="submit" name="submit" value={% trans "Subscribe" %} />
</form>
