{% load i18n %}

<h1>{{ title|default:_("Login to Your Account") }}</h1>
<form method="post" action="{% url 'login' %}">
    {% csrf_token %}
    <input type="hidden" name="next" value="{{ next }}" />
    <table>
        {{ form.as_table }}
        <tr>
            <td></td>
            <td>
                <input type="submit" value="{{ submit|default:_("Login") }}" />
                <br />
            <p>
                <a href="{% url 'register' %}">{% trans "Register" %}</a> &#183;
                <a href="{% url 'password_reset' %}">{% trans "Lost password?" %}</a>
            </p>
            </td>
        </tr>
    </table>
</form>
