{% extends "cms_qe/auth/email/base.html" %}
{% load i18n %}

{% block content %}
    {% autoescape off %}
        <h1>{% trans "Email confirmation address" %}</h1>
        <p>
            {% blocktrans %}
                Hello {{ username }},
                please confirm your email address, to activate your account. If you
                received this email by mistake, simply ignore it.
            {% endblocktrans %}
        </p>
        <a href="{{ activation_url }}">
            {% trans "Confirm email address" %}
        </a>
    {% endautoescape %}
{% endblock content %}
