{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
    <p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>
    <p><a href="{{ login_url }}">{% trans 'Log in' %}</a></p>
{% endblock %}
