{% load cms_qe_table_filters %}

<tbody>
    {% for item in items %}
        <tr>
            {% for column in item %}
                <td>{{ column|cms_qe_table_value }}</td>
            {% endfor %}
        </tr>
    {% endfor %}
</tbody>
