{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
    <p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>
    <form method="post">
        {% csrf_token %}
        <table>
            {{ form.as_table }}
            <tr>
                <td></td>
                <td>
                    <input type="submit" value="{% trans 'Change my password' %}" />
                </td>
            </tr>
        </table>
    </form>
{% endblock %}
