{% load thumbnail %}
<div>
    {% for image in folder_images %}
        <a href="{{ image.url }}">
            <img src="{% thumbnail image.file 460x308 crop="True" upscale="True" %}" alt="{{ image.label }}">
        </a>
    {% endfor %}
</div>
