{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}

{% block content %}
    {% if validlink %}
        <p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>

        <form method="post">
            {% csrf_token %}
            {{ form.new_password1.errors }}
            <p class="aligned wide"><label for="id_new_password1">{% trans 'New password:' %}</label>{{ form.new_password1 }}</p>
            {{ form.new_password2.errors }}
            <p class="aligned wide"><label for="id_new_password2">{% trans 'Confirm password:' %}</label>{{ form.new_password2 }}</p>
            <p><input type="submit" value="{% trans 'Change my password' %}" /></p>
        </form>
    {% else %}
        <p>{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}</p>
    {% endif %}
{% endblock %}
