{% extends "cms_qe/auth/email/base.html" %}
{% load i18n %}

{% block content %}
    <h1>{% blocktrans %}Password reset on {{ site_name }}{% endblocktrans %}</h1>

    <p>
        {% blocktrans %}
            You're receiving this email because you requested a password reset for your user account at {{ site_name }}.
        {% endblocktrans %}
    </p>

    <p> {% trans "Please go to the following page and choose a new password:" %} </p>

    <a href="
            {% block reset_link %}
                {{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}
            {% endblock %}
    ">
        {% trans "Reset password" %}
    </a>

    <p>{% trans "Your username, in case you've forgotten:" %} {{ user.get_username }}</p>
{% endblock %}
