{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Login is locked" %}{% endblock %}

{% block content %}
    <p>{% blocktrans %}Too many attempts to log in. Please try again later.{% endblocktrans %}</p>
{% endblock %}
